@@ -9,17 +9,17 @@ Finally we will get list of TFs that potentially binds to a specific gene.
 """
 
 from .motif_analysis_utility import is_genome_installed
-from .process_bed_file import peak2fasta, read_bed, remove_zero_seq
+from .process_bed_file import peak2fasta, read_bed, remove_zero_seq, check_peak_format
 from .tfinfo_core import (load_TFinfo, load_TFinfo_from_parquets,
                           make_TFinfo_from_scanned_file, TFinfo, scan_dna_for_motifs)
 from .reference_genomes import SUPPORTED_REF_GENOME
 from .tss_annotation import get_tss_info
 from .process_cicero_data import integrate_tss_peak_with_cicero
 from . import process_cicero_data
-from .motif_data import load_motifs, MOTIFS_LIST#, PATH_TO_MOTIF_DATA, PFM_PATHS, MOTIFS_PATH_DICT, 
+from .motif_data import load_motifs, MOTIFS_LIST#, PATH_TO_MOTIF_DATA, PFM_PATHS, MOTIFS_PATH_DICT,
 
 
-__all__ = ["is_genome_installed", "peak2fasta", "read_bed", "remove_zero_seq",
+__all__ = ["is_genome_installed", "peak2fasta", "read_bed", "remove_zero_seq",  "check_peak_format",
            "load_TFinfo", "load_TFinfo_from_parquets",
            "make_TFinfo_from_scanned_file",
            "TFinfo", "scan_dna_for_motifs", "SUPPORTED_REF_GENOME",
