@@ -131,7 +131,7 @@ class TFinfo():
 
     """
 
-    def __init__(self, peak_data_frame, ref_genome):
+    def __init__(self, peak_data_frame, ref_genome, genomes_dir=None):
         """
         Instantiate TFinfo object.
 
@@ -140,8 +140,9 @@ class TFinfo():
 
            ref_genome (str): reference genome name that was used in DNA peak generation.
 
-        """
+           genomes_dir (str): Installation directory of Genomepy reference genome data. If None, use default Genomepy installation directory.
 
+        """
 
         self.easy_log = pd.DataFrame()
         self.__addLog("initiation")
@@ -156,6 +157,8 @@ class TFinfo():
 
         self.ref_genome = ref_genome
 
+        self.genomes_dir = genomes_dir
+
         # check ref_genome is supported or not
         if ref_genome in SUPPORTED_REF_GENOME.ref_genome.values:
             self.species = SUPPORTED_REF_GENOME.species[SUPPORTED_REF_GENOME.ref_genome==ref_genome].values[0]
@@ -164,7 +167,7 @@ class TFinfo():
             self.species = "not_in_the_default_species_list"
 
         # check  genome installation
-        if not is_genome_installed(ref_genome=ref_genome):
+        if not is_genome_installed(ref_genome=ref_genome, genomes_dir=self.genomes_dir):
             raise ValueError(f"ref_genome: {ref_genome} is not installed. TFinfo initiation failed.")
 
         self.scanned_df = None
@@ -344,6 +347,21 @@ class TFinfo():
                 if verbose:
                     print(f" Default motif for {self.species}: {self.motif_db_name}. \n For more information about the motif data, please see http://cisbp.ccbr.utoronto.ca. \n")
 
+            elif self.species in ["Axolotl"]:
+                self.motif_db_name = 'JASPAR2020_vertebrates.pfm'
+
+                # Load JASPAR motif from gimmemotifs data
+                from gimmemotifs.motif import read_motifs
+                from gimmemotifs.motif import MotifConfig
+                config = MotifConfig()
+                motif_dir = config.get_motif_dir()
+                path = os.path.join(motif_dir, "JASPAR2020_vertebrates.pfm")
+                motifs = read_motifs(path)
+
+                self.TF_formatting = True
+                if verbose:
+                    print(f" Default motif for {self.species}: {self.motif_db_name}. \n For more information about the motif data, please see https://gimmemotifs.readthedocs.io/en/master/overview.html \n")
+
             else:
                 raise ValueError(f"We don't have default motifs for your species, Please specify motif data by yourself.")
 
@@ -390,7 +408,7 @@ class TFinfo():
 
 
         # Get DNA sequences
-        target_sequences = peak2fasta(self.all_peaks, self.ref_genome)
+        target_sequences = peak2fasta(peak_ids=self.all_peaks, ref_genome=self.ref_genome, genomes_dir=self.genomes_dir)
         # Remove DNA sequence with zero length
         target_sequences = remove_zero_seq(fasta_object=target_sequences)
 
@@ -710,7 +728,7 @@ def _get_dic_motif2TFs(species, motifs, TF_evidence_level="direct_and_indirect",
             for key in dic_motif2TFs.keys():
                 dic_motif2TFs[key] = [tf.capitalize() for tf in dic_motif2TFs[key]]
 
-        elif species in ["Human", "S.cerevisiae", "Arabidopsis"]:
+        elif species in ["Human", "S.cerevisiae", "Arabidopsis", "Axolotl"]:
             for key in dic_motif2TFs.keys():
                 dic_motif2TFs[key] = [tf.upper() for tf in dic_motif2TFs[key]]
 
