@@ -628,24 +628,6 @@ class modified_VelocytoLoom():
         diffusor = Diffusion()
         self.diffused = diffusor.diffuse(starting_p, self.tr, n_steps=n_steps, mode=mode)[0]
 
-    def plot_mc_results_as_density(self, args={}):
-        """
-        this function plot the results of mc chain simulation in velocyto method.
-        """
-        diffused_n = self.diffused - np.percentile(self.diffused, 3)
-        diffused_n /= np.percentile(diffused_n, 97)
-        diffused_n = np.clip(diffused_n, 0, 1)
-        #diffused_n = tv.diffused
-        #plt.figure(None,(7,7))
-        args_ = {"alpha": 0.5, "s": 50, "lw": 0., "edgecolor":"", "cmap": "viridis_r", "rasterized": True}
-        args_.update(args)
-
-        plt.scatter(self.embedding[self.ixs_mcmc, 0], self.embedding[self.ixs_mcmc, 1],
-                        c=diffused_n, **args_)
-        plt.axis("off")
-        cax = plt.axes([0.85, 0.1, 0.075, 0.8])
-        plt.colorbar()
-        plt.axis("off")
 
 
 
